@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2013 - 2016, Phoronix Media
-	Copyright (C) 2013 - 2016, Michael Larabel
+	Copyright (C) 2013 - 2017, Phoronix Media
+	Copyright (C) 2013 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -29,14 +29,14 @@ class debug_self_test implements pts_option_interface
 	{
 		define('PHOROMATIC_PROCESS', true);
 		$commands = array(
-			'detailed_system_info' => null,
+			'system_info' => null,
 			'list_available_tests' => null,
 			'list_available_suites' => null,
 			'info' => array('pts/all'),
 			'clone_openbenchmarking_result' => array('1107247-LI-MESACOMMI48', '1509040-HA-GCCINTELS17', '1508201-HA-GTX95073337', '1508233-HA-INTELSKYL16'),
-			'refresh_graphs' => array('1107247-LI-MESACOMMI48'),
+			'refresh_graphs' => array('1107247-LI-MESACOMMI48', '1711094-AL-ZOTACGEFO61', '1711073-AL-GTX770TIL45', '1710268-AL-CPUTESTS119'),
 			'result_file_to_text' => array('1107247-LI-MESACOMMI48'),
-			'merge_results' => array('1107247-LI-MESACOMMI48', '1509040-HA-GCCINTELS17', '1508201-HA-GTX95073337', '1508233-HA-INTELSKYL16'),
+			'merge_results' => array('1107247-LI-MESACOMMI48', '1509040-HA-GCCINTELS17', '1508201-HA-GTX95073337', '1508233-HA-INTELSKYL16', '1711094-AL-ZOTACGEFO61', '1711073-AL-GTX770TIL45', '1710268-AL-CPUTESTS119'),
 			'diagnostics' => null,
 			'dump_possible_options' => null,
 			'debug_render_test' => null,
