@@ -86,8 +86,7 @@ var $PDFVersion;         // PDF version number
 *                               Public methods                                 *
 *                                                                              *
 *******************************************************************************/
-function FPDF($orientation='P', $unit='mm', $size='A4')
-{
+public function __construct($orientation='P',$unit='mm',$size='A4') {
 	// Some checks
 	$this->_dochecks();
 	// Initialization of properties
