@@ -40,6 +40,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	// Run bits
 	private $expected_trial_run_count = 0;
 	private $trial_run_count_current = 0;
+	private $current_saved_test_identifier = null;
 
 	public function __construct()
 	{
@@ -211,7 +212,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 		$this->progress_tab_count = 2;
 		$this->progress_string_length = strlen($download_string);
 	}
-	public function display_interrupt_message($message)
+	public function display_interrupt_message($message, $prefix_tag = 'NOTICE', $text_color = 'gray')
 	{
 		if($message == null)
 		{
@@ -220,7 +221,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 
 		$terminal_width = pts_client::terminal_width() > 1 ? pts_client::terminal_width() : $terminal_width;
 		$text_width = $terminal_width - (strlen($this->tab) * 3);
-		echo PHP_EOL . $this->tab . $this->tab . pts_client::cli_colored_text(wordwrap('[NOTICE] ' . $message, $text_width, PHP_EOL . $this->tab . $this->tab), 'gray', true) . PHP_EOL;
+		echo PHP_EOL . $this->tab . $this->tab . pts_client::cli_colored_text(wordwrap(($prefix_tag != null ? '[' . $prefix_tag . '] ' : null) . $message, $text_width, PHP_EOL . $this->tab . $this->tab), $text_color, true) . PHP_EOL;
 	}
 	public function test_install_progress_start($process)
 	{
@@ -294,6 +295,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	}
 	public function test_run_start(&$test_run_manager, &$test_result)
 	{
+		$this->current_saved_test_identifier = $test_run_manager->get_results_identifier();
 		$test_title_string = $test_result->test_profile->get_title() . ($test_result->test_profile->get_app_version() != null ? ' ' . $test_result->test_profile->get_app_version() : null) . ':' . PHP_EOL . $this->tab . $test_result->test_profile->get_identifier();
 
 		if(($test_description = $test_result->get_arguments_description()) != false)
@@ -474,9 +476,17 @@ class pts_concise_display_mode implements pts_display_mode_interface
 
 		echo $end_print;
 	}
+	public function test_run_success_inline($test_result_orig)
+	{
+		$test_result = clone $test_result_orig;
+		$test_result->sort_results_by_performance();
+		$test_result->test_result_buffer->buffer_values_reverse();
+		echo pts_result_file_output::test_result_to_text($test_result, pts_client::terminal_width(), true, $this->current_saved_test_identifier);
+		echo PHP_EOL;
+	}
 	public function test_run_error($error_string)
 	{
-		echo $this->tab . $this->tab . pts_client::cli_colored_text($error_string, 'red', true) . PHP_EOL;
+		echo PHP_EOL . $this->tab . $this->tab . pts_client::cli_colored_text($error_string, 'red', true) . PHP_EOL;
 	}
 	public function generic_prompt($prompt_string)
 	{
