@@ -197,6 +197,7 @@ class phodevi_disk extends phodevi_device_interface
 					if(substr($line, 0, 1) == '<' && ($model_end = strpos($line, '>')) !== false && strpos($line, 'DVD') === false && strpos($line, 'ATAPI') === false)
 					{
 						$disk = self::prepend_disk_vendor(substr($line, 1, ($model_end - 1)));
+						$disk = trim(str_replace(array('SATA'), null, $disk));
 						array_push($disks, $disk);
 					}
 				}
@@ -441,6 +442,22 @@ class phodevi_disk extends phodevi_device_interface
 				$extra_details = trim(substr($md, $x + 7));
 			}
 		}
+		if($extra_details == null && strpos($device['device'], 'bcache') !== false)
+		{
+			// Show Bcache details
+			$d = basename($device['device']);
+			if(is_file('/sys/block/' . $d . '/bcache/cache_mode'))
+			{
+				$cache_mode = file_get_contents('/sys/block/' . $d . '/bcache/cache_mode');
+				if(($x = strpos($cache_mode, '[')) !== false)
+				{
+					$cache_mode = substr($cache_mode, $x + 1);
+					$cache_mode = substr($cache_mode, 0, strpos($cache_mode, ']'));
+
+					$extra_details = trim('Bcache ' . $cache_mode);
+				}
+			}
+		}
 
 
 		return $extra_details;
