@@ -274,14 +274,14 @@ class phodevi extends phodevi_base
 	}
 	public static function system_centralized_view($return_as_string = true)
 	{
-		$core_count = phodevi::is_linux() ? phodevi_cpu::cpuinfo_core_count() : phodevi::read_property('cpu', 'core-count');
-		$thread_count = phodevi_cpu::cpuinfo_thread_count();
+		$core_count = phodevi::read_property('cpu', 'physical-core-count');
+		$thread_count = phodevi::read_property('cpu', 'thread-count');
 
 		$sys = array(
 			'Processor' => phodevi::read_property('cpu', 'model-and-speed'),
 				array(
 				'Core Count' => $core_count,
-				'Thread Count' => $core_count == $thread_count ? '' : $thread_count, // don't show thread count if it's same as core count
+				'Thread Count' => !empty($core_count) && $core_count == $thread_count ? '' : $thread_count, // don't show thread count if it's same as core count
 				'Extensions' => phodevi_cpu::instruction_set_extensions(),
 			//	'Virtualization' => (phodevi_cpu::virtualization_technology() ? phodevi_cpu::virtualization_technology() : ''),
 				'Cache Size' => phodevi::read_property('cpu', 'cache-size-string'),
@@ -340,7 +340,7 @@ class phodevi extends phodevi_base
 						}
 					}
 				}
-				else if(!empty($in))
+				else if(true || !empty($in)) // TODO this check not needed anymore?
 				{
 					if(!empty($tabled))
 					{
@@ -613,7 +613,7 @@ class phodevi extends phodevi_base
 
 			if(($mins_end_pos = strpos($uptime_output, ' mins')) !== false)
 			{
-				$mins_output = substr($uptime_output, 0, $day_end_pos);
+				$mins_output = substr($uptime_output, 0, $mins_end_pos);
 				$mins_output = substr($mins_output, strrpos($mins_output, ' ') + 1);
 
 				if(is_numeric($mins_output))
