@@ -131,7 +131,9 @@ class cpu_freq extends phodevi_sensor
 	private function cpu_freq_bsd()
 	{
 		//TODO test on BSD and implement per-core monitoring
-		return phodevi_bsd_parser::read_sysctl('dev.cpu.0.freq');
+		$freq = phodevi_bsd_parser::read_sysctl('dev.cpu.0.freq');
+		if(is_numeric($freq) && $freq != '')
+			return $freq;
 	}
 	private function cpu_freq_macosx()
 	{
