@@ -116,7 +116,7 @@ class pts_ResultFileTable extends pts_Table
 				{
 					$result_tests[$result_counter] = new pts_graph_ir_value($result_object->test_profile->get_identifier_base_name() . ': ' . $result_object->get_arguments_description());
 					$result_tests[$result_counter]->set_attribute('title', $result_object->get_arguments_description());
-					$result_tests[$result_counter]->set_attribute('href', 'http://openbenchmarking.org/test/' . $result_object->test_profile->get_identifier());
+					$result_tests[$result_counter]->set_attribute('href', 'https://openbenchmarking.org/test/' . $result_object->test_profile->get_identifier());
 				}
 				else if($result_object->test_profile->get_title() != null)
 				{
