@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -391,13 +391,39 @@ class pts_network
 			echo PHP_EOL . 'The file_uploads option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
 		}
 	}
+	public static function get_active_network_interface()
+	{
+		$dev = '';
+
+		// try and get the device with the default route
+		if ($ip = pts_client::executable_in_path('ip')) {
+			$out = shell_exec("$ip route 2>&1");
+			$start = strpos($out,' dev ')+5;
+			$dev = substr($out, $start, strpos($out,' ', $start) - $start);
+		}
+
+		// we grab the last field of the `netstat -nr` output, betting on *bsd not expiring it's default route
+		if(empty($dev) && $netstat = pts_client::executable_in_path('netstat')) {
+			$out = shell_exec("$netstat -rn 2>&1");
+			$lines = explode("\n", $out);
+			foreach ($lines as $line) {
+				$start = substr($line,0,7);
+				if ($start == '0.0.0.0' || $start === 'default') {
+					$dev = trim(substr(trim($line),strrpos($line,' ')));
+					return $dev;
+				}
+			}
+		}
+		return $dev;
+	}
 	public static function get_local_ip()
 	{
 		$local_ip = false;
+		$interface = self::get_active_network_interface();
 
 		if(($ifconfig = pts_client::executable_in_path('ifconfig')))
 		{
-			$ifconfig = shell_exec($ifconfig . ' 2>&1');
+			$ifconfig = shell_exec($ifconfig . " $interface 2>&1");
 			$offset = 0;
 			while(($ipv4_pos = strpos($ifconfig, 'inet addr:', $offset)) !== false)
 			{
@@ -442,16 +468,26 @@ class pts_network
 	{
 		$mac = false;
 
-		foreach(pts_file_io::glob('/sys/class/net/*/operstate') as $net_device_state)
+		if ($interface = self::get_active_network_interface())
 		{
-			if(pts_file_io::file_get_contents($net_device_state) == 'up')
+			$addr =  "/sys/class/net/$interface/address";
+			if(is_file($addr))
 			{
-				$addr = dirname($net_device_state) . '/address';
+				$mac = pts_file_io::file_get_contents($addr);
+			}
+		}
 
-				if(is_file($addr))
+		if (empty($mac)) {
+			foreach(pts_file_io::glob('/sys/class/net/*/operstate') as $net_device_state)
+			{
+				if(pts_file_io::file_get_contents($net_device_state) == 'up')
 				{
-					$mac = pts_file_io::file_get_contents($addr);
-					break;
+					$addr = dirname($net_device_state) . '/address';
+					if(is_file($addr))
+					{
+						$mac = pts_file_io::file_get_contents($addr);
+						break;
+					}
 				}
 			}
 		}
@@ -465,6 +501,11 @@ class pts_network
 				$hw_addr = substr($ifconfig, $hwaddr_pos);
 				$hw_addr = substr($hw_addr, (strpos($hw_addr, ' ') + 1));
 				$hw_addr = substr($hw_addr, 0, strpos($hw_addr, ' '));
+				if(($x = strpos($hw_addr, PHP_EOL)) != false)
+				{
+					$hw_addr = substr($hw_addr, 0, $x);
+				}
+
 				$mac = $hw_addr;
 
 				if($mac != null)
@@ -474,6 +515,41 @@ class pts_network
 				$offset = $hwaddr_pos + 1;
 			}
 		}
+		if(empty($mac) && ($netstat = pts_client::executable_in_path('netstat')))
+		{
+			// Needed on at least OpenBSD as their `ifconfig` does not expose the MAC address
+			$netstat = shell_exec($netstat . ' -in 2>&1');
+			foreach(explode(PHP_EOL, $netstat) as $line)
+			{
+				$line = explode(' ', $line);
+				foreach($line as $i => $r)
+				{
+					if($r == null)
+						unset($line[$i]);
+				}
+				$line = array_values($line);
+
+				if(!isset($line[3]))
+				{
+					continue;
+				}
+
+				$address = explode(':', $line[3]);
+
+				if(count($address) == 6 && $address[0] != '00' && $address[5] != '00')
+				{
+					foreach($address as $seg)
+					{
+						if(strlen($seg) != 2)
+						{
+							continue;
+						}
+					}
+
+					$mac = $line[3];
+				}
+			}
+		}
 
 		return $mac;
 	}
@@ -484,24 +560,52 @@ class pts_network
 		if($wol_support === null)
 		{
 			$wol_support = array();
-			if(is_dir('/sys/class/net') && pts_client::executable_in_path('ethtool'))
+			if(is_dir('/sys/class/net'))
 			{
-				foreach(pts_file_io::glob('/sys/class/net/*') as $net_device)
+				if(pts_client::executable_in_path('ethtool'))
 				{
-					if(is_readable($net_device . '/operstate') && trim(file_get_contents($net_device . '/operstate')) != 'up')
+					foreach(pts_file_io::glob('/sys/class/net/*') as $net_device)
 					{
-						continue;
-					}
+						if(!is_readable($net_device . '/operstate') || trim(file_get_contents($net_device . '/operstate')) != 'up')
+						{
+							continue;
+						}
 
-					$net_name = basename($net_device);
-					$ethtool_output = shell_exec('ethtool ' . $net_name . ' 2>&1');
-					if(($x = stripos($ethtool_output, 'Supports Wake-on: ')) !== false)
+						$net_name = basename($net_device);
+						$ethtool_output = shell_exec('ethtool ' . $net_name . ' 2>&1');
+						if(($x = stripos($ethtool_output, 'Supports Wake-on: ')) !== false)
+						{
+							$ethtool_output = substr($ethtool_output, $x + strlen('Supports Wake-on: '));
+							$ethtool_output = trim(substr($ethtool_output, 0, strpos($ethtool_output, PHP_EOL)));
+							$wol_support[$net_name] = $net_name . ': ' . $ethtool_output;
+						}
+
+					}
+				}
+				if(empty($wol_support) && pts_client::executable_in_path('nmcli'))
+				{
+					foreach(pts_file_io::glob('/sys/class/net/*') as $net_device)
 					{
-						$ethtool_output = substr($ethtool_output, $x + strlen('Supports Wake-on: '));
-						$ethtool_output = trim(substr($ethtool_output, 0, strpos($ethtool_output, PHP_EOL)));
-						$wol_support[$net_name] = $net_name . ': ' . $ethtool_output;
-					}
+						if(!is_readable($net_device . '/operstate') || trim(file_get_contents($net_device . '/operstate')) != 'up')
+						{
+							continue;
+						}
 
+						$net_name = basename($net_device);
+						$ethtool_output = shell_exec('nmcli c show ' . $net_name . ' 2>&1');
+						if(($x = stripos($ethtool_output, '.wake-on-lan:')) !== false)
+						{
+							$ethtool_output = substr($ethtool_output, $x + strlen('.wake-on-lan:'));
+							$ethtool_output = trim(substr($ethtool_output, 0, strpos($ethtool_output, PHP_EOL)));
+
+							if(strpos($ethtool_output, '1') || strpos($ethtool_output, 'default'))
+							{
+								shell_exec('nmcli connection modify ' . $net_name . ' 802-3-ethernet.wake-on-lan magic 2>&1'); // TODO this really needed?
+								$wol_support[$net_name] = $net_name . ': g';
+							}
+						}
+
+					}
 				}
 			}
 		}
