@@ -222,7 +222,6 @@ class phoromatic_result implements pts_webui_interface
 			}
 
 			$result_file = new pts_result_file(null, true);
-			$result_file->set_title('Phoromatic Results');
 			if(!empty($result_files))
 			{
 				$attributes = array('new_result_file_title' => $result_file_title);
@@ -310,7 +309,15 @@ class phoromatic_result implements pts_webui_interface
 				return;
 			}
 
-			$main .= '<h1>' . $result_file->get_title() . '</h1>';
+			if(count($result_files) > 1)
+			{
+				$main .= '<h1>Phoromatic Comparison</h1>';
+			}
+			else
+			{
+				$main .= '<h1>' . ($result_file->get_title() != null ? $result_file->get_title() : 'Phoromatic Results') . '</h1>';
+				$main .= '<p>' . $result_file->get_description() . '</p>';
+			}
 			$main .= phoromatic_annotate_entry('RESULT', implode(',', $upload_ids), 'TOP');
 
 			if($result_file->get_system_count() == 1 || ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)))
